@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdataitem.h 421129 2005-06-02 09:33:12Z trueg $
+ * $Id: k3bdataitem.h 487368 2005-12-10 13:18:58Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -64,6 +64,13 @@ class K3bDataItem
    */
   const QString& writtenName() const { return m_writtenName; }
 
+  /**
+   * \return the pure name used in the Iso9660 tree.
+   *
+   * This is only valid after a call to @p K3bDataDoc::prepareFilenames()
+   */
+  const QString& iso9660Name() const { return m_rawIsoName; }
+
   /**
    * Returns the path of the item as written to the CD or DVD image.
    *
@@ -73,11 +80,19 @@ class K3bDataItem
    */
   virtual QString writtenPath() const;
 
+  virtual QString iso9660Path() const;
+
   /**
    * Used to set the written name by @p K3bDataDoc::prepareFilenames()
    */
   void setWrittenName( const QString& s ) { m_writtenName = s; }
 
+
+  /**
+   * Used to set the pure Iso9660 name by @p K3bDataDoc::prepareFilenames()
+   */
+  void setIso9660Name( const QString& s ) { m_rawIsoName = s; }
+
   virtual K3bDataItem* nextSibling() const;
 	
   /** returns the path to the file on the local filesystem */
@@ -132,6 +147,7 @@ class K3bDataItem
 
  private:
   QString m_writtenName;
+  QString m_rawIsoName;
 
   K3bDataDoc* m_doc;
   K3bDirItem* m_parentDir;
